@@ -10,9 +10,10 @@ from importlib.metadata import version
 
 #__version__ = version("ccs")
 
-# from ccs.ase_calculator.ccs_ase_calculator import CCS
-# from ccs.scripts.ccs_build_db import main as ccs_build_db
-# from ccs.scripts.ccs_export_sktable import main as ccs_export_sktable
+from ccs_fit.ase_calculator.ccs_ase_calculator import CCS as CCS_calc
+from ccs_fit.scripts.ccs_build_db import ccs_build_db
+from ccs_fit.scripts.ccs_export_sktable import write_dftb_spline as ccs_export_sktable
 from ccs_fit.scripts.ccs_fetch import ccs_fetch as ccs_fetch
 from ccs_fit.fitting.main import twp_fit as ccs_fit
-# from ccs.scripts.ccs_validate import main as ccs_validate
+from ccs_fit.scripts.ccs_validate import ccs_validate
+from ccs_fit.scripts.ccs_export_FF import write_FF
